@@ -12,8 +12,8 @@ from typing import TypeVar
 from typing_extensions import Protocol
 from typing_extensions import runtime_checkable
 
+from . import _hypothesis
 from ._utils.misc import BoundType
-from ._utils.misc import NotKnownMutableType
 from ._utils.misc import UnresolvedClassAttribute
 from ._utils.misc import fully_qualified_name
 from ._utils.misc import is_not_known_mutable_type
@@ -52,6 +52,7 @@ class PhantomMeta(abc.ABCMeta):
 
 
 T = TypeVar("T", covariant=True)
+U = TypeVar("U")
 
 
 Derived = TypeVar("Derived", bound="PhantomBase")
@@ -117,7 +118,7 @@ class Phantom(PhantomBase, Generic[T]):
     #
     # When subclassing, the bound of the new type must be a subtype of the bound
     # of the super class.
-    __bound__: ClassVar[NotKnownMutableType]
+    __bound__: ClassVar[type]
     __abstract__: ClassVar[bool]
 
     def __init_subclass__(
@@ -132,6 +133,11 @@ class Phantom(PhantomBase, Generic[T]):
         resolve_class_attr(cls, "__predicate__", predicate)
         cls._resolve_bound(bound)
 
+        if _hypothesis.register_type_strategy is not None and not cls.__abstract__:
+            strategy = cls.__register_strategy__()
+            if strategy is not None:
+                _hypothesis.register_type_strategy(cls, strategy)
+
     @classmethod
     def _interpret_implicit_bound(cls) -> BoundType:
         def discover_bounds() -> Iterable[type]:
@@ -190,3 +196,7 @@ class Phantom(PhantomBase, Generic[T]):
         except BoundError:
             return False
         return cls.__predicate__(instance)
+
+    @classmethod
+    def __register_strategy__(cls) -> _hypothesis.HypothesisStrategy | None:
+        return None
